@@ -50,7 +50,7 @@
 #'There are many options to choose from so please
 #'read the documentation of these packages. "\code{Default=grDevices}
 #' @author
-#' Code based on the \link[WaveletComp]{reconstruct} function of the 'WaveletComp' R package
+#' Code based on the reconstruct function of the 'WaveletComp' R package
 #' which is based on the wavelet 'MATLAB' code written by Christopher Torrence and Gibert P. Compo (1998).
 #' The assignment of the standard deviation of the uncertainty of the wavelet
 #' is based on the work of Gabor (1946) and Russell et al., (2016)
@@ -78,11 +78,10 @@
 #'Morlet, Jean, Georges Arens, Eliane Fourgeau, and Dominique Glard.
 #'"Wave propagation and sampling theory—Part I: Complex signal and scattering in multilayered media.
 #'" Geophysics 47, no. 2 (1982): 203-221.
-#' \url{https://pubs.geoscienceworld.org/geophysics/article/47/2/203/68601/Wave-propagation-and-sampling-theory-Part-I}
 #'
 #'J. Morlet, G. Arens, E. Fourgeau, D. Giard;
 #' Wave propagation and sampling theory; Part II, Sampling theory and complex waves.
-#'Geophysics 1982 47 (2): 222–236. \url{https://pubs.geoscienceworld.org/geophysics/article/47/2/222/68604/Wave-propagation-and-sampling-theory-Part-II}
+#'Geophysics 1982 47 (2): 222–236.
 #'
 #'
 #'@examples
@@ -166,7 +165,6 @@
 #' @importFrom stats median
 #' @importFrom stats fft
 #' @importFrom DescTools Closest
-#' @importFrom WaveletComp reconstruct
 #' @importFrom RColorBrewer brewer.pal.info
 #' @importFrom RColorBrewer brewer.pal
 #' @importFrom grDevices colorRampPalette
@@ -304,7 +302,6 @@ extract_signal_standard_deviation <- function(wavelet = NULL,
     }
     plot_wavelet(
       wavelet = wavelet,
-      plot.COI = TRUE,
       n.levels = 100,
       palette_name = palette_name,
       color_brewer= color_brewer,
@@ -393,7 +390,6 @@ extract_signal_standard_deviation <- function(wavelet = NULL,
 
     plot_wavelet(
       wavelet = data_set_time_wt,
-      plot.COI = TRUE,
       n.levels = 100,
       palette_name = "rainbow",
       color_brewer= "grDevices",
