@@ -127,8 +127,6 @@
 #' @importFrom doSNOW registerDoSNOW
 #' @importFrom utils txtProgressBar
 #' @importFrom utils setTxtProgressBar
-#' @importFrom tcltk setTkProgressBar
-#' @importFrom tcltk setTkProgressBar
 #' @importFrom foreach foreach
 #' @importFrom stats runif
 #' @importFrom stats sd
@@ -246,11 +244,11 @@ sum_power_sedrate  <- function(red_noise = NULL,
   if (run_multicore == TRUE) {
     numCores <- detectCores()
     cl <- parallel::makeCluster(numCores - 2)
-    doSNOW::registerDoSNOW(cl)
+    registerDoSNOW(cl)
   }else{
     numCores <- 1
     cl <- parallel::makeCluster(numCores)
-    doSNOW::registerDoSNOW(cl)
+    registerDoSNOW(cl)
   }
 
 
@@ -267,7 +265,7 @@ sum_power_sedrate  <- function(red_noise = NULL,
 
 
   fit <-
-    foreach (ijk = 1:simulations, .options.snow = opts) %dopar% {
+    foreach (ijk = 1:simulations, .options.parallel   = opts) %dopar% {
       fits <- matrix(data = NA,
                      nrow = nrow(testsedrates),
                      ncol = 2)
